@@ -1,4 +1,5 @@
+from libvis_mods import config # this line has to come before main
+
 from .main import install, uninstall, installed, develop
 from .init_methods import init, init_file, init_dir
 from . import tools
-from . import config_gen
