@@ -1,19 +1,21 @@
 """ Cli interface for libvis modules and dev """
 import click
-import libvis_mods as wm
+import libvis_mods
 
-from libvis_mods.config_gen import with_libvis_config
+from libvis_mods.config import with_libvis_config
 from libvis_mods.publish import publish
-from libvis_mods.utils import only_required_kwargs_call
+from libvis_mods.utils import only_required_kwargs_call, configure_cli_logging
 from libvis_mods.download import repository
+from loguru import logger as log
 
-from libvis_mods.paths_config import (
+from libvis_mods.config.paths import (
     web_user_mods, python_user_mods
 )
 
 
 @click.group()
-def cli(): pass
+def cli():
+    configure_cli_logging('INFO')
 
 name = click.argument('modname', required=False)
 back = click.argument('back_src'
@@ -32,23 +34,35 @@ files = lambda x: back( front(
 @name
 @files
 def install(*args, **kwargs):
-    """ Install a module from directory """
-    print('Arguments', kwargs)
-    only_required_kwargs_call(
-        wm.install, *args, **kwargs)
+    """ Install a module from directory.
+
+        Arguments can be omitted if the command is run
+        in a directory with libvis-mod.conf
+    """
+    log.debug('install arguments: {}', kwargs)
+    if any([
+        'modname' not in kwargs,
+        'front_src' not in kwargs,
+        'back_src' not in kwargs
+    ]):
+        log.error('Please provide install arguments, `libvis-mods install --help`, or run in a directory with libvis-mod.conf')
+        return 1
+
+    return only_required_kwargs_call(
+        libvis_mods.install, *args, **kwargs)
 
 
 @cli.command('list')
 def list_():
     """ list installed modules """
-    mods = wm.installed()
+    mods = libvis_mods.installed()
     print("\n".join(mods))
 
 @cli.command()
 @name
 def uninstall(**kwargs):
     """ Uninstall module """
-    wm.uninstall(kwargs['modname'])
+    return libvis_mods.uninstall(kwargs['modname'])
 
 ## ## ## Utils ## ## ##
 
@@ -80,22 +94,22 @@ def where(request):
 @files
 def develop(*args, **kwargs):
     """ Run the web server in development mode with hot reload """
-    print(args, kwargs)
-    only_required_kwargs_call(
-        wm.develop, *args, **kwargs)
+    log.debug("debug args={}  kwargs={}",args, kwargs)
+    return only_required_kwargs_call(
+        libvis_mods.develop, *args, **kwargs)
 
 
 @cli.command()
 @click.option('-o', '--output-dir', 'output_dir', default='.')
 @name
 def init_file(modname, output_dir):
-    wm.init_file(modname, output_dir=output_dir)
+    libvis_mods.init_file(modname, output_dir=output_dir)
 
 @cli.command()
 @click.option('-o', '--output-dir', 'output_dir', default='.')
 @name
 def init_dir(modname, output_dir):
-    wm.init_dir(modname, output_dir=output_dir)
+    libvis_mods.init_dir(modname, output_dir=output_dir)
 
 
 cli.command()(publish)
